@@ -2,7 +2,7 @@
 //Activities Hack
 $(function()
 {
-    if ($(".portlet.portletCollection").find(".portletItem") == 0)
+    if ($(".portlet.portletCollection").find(".portletItem").length == 0)
     {
         $(".portlet.portletCollection").hide();
     }
